diff --git a/src/main.cpp b/src/main.cpp
index 803ba4a..1216823 100644
--- a/src/main.cpp
+++ b/src/main.cpp
@@ -58,6 +58,8 @@ private:
     vk::raii::Queue m_presentQueue{ nullptr };
     vk::raii::DeviceMemory m_vertexBufferMemory{ nullptr };
     vk::raii::Buffer m_vertexBuffer{ nullptr };
+    vk::raii::DeviceMemory m_indexBufferMemory{ nullptr };
+    vk::raii::Buffer m_indexBuffer{ nullptr };
     vk::raii::SwapchainKHR m_swapChain{ nullptr };
     std::vector<vk::Image> m_swapChainImages;
     vk::Format m_swapChainImageFormat;
@@ -101,6 +103,7 @@ private:
         createFramebuffers();
         createCommandPool();
         createVertexBuffer();
+        createIndexBuffer();
         createCommandBuffers();
         createSyncObjects();
     }
@@ -679,11 +682,12 @@ private:
         );
         commandBuffer.setScissor(0, scissor);
 
-        std::array<vk::Buffer,1> vertexBuffers { m_vertexBuffer };
-        std::array<vk::DeviceSize,1> offsets { 0 };
-        commandBuffer.bindVertexBuffers( 0, vertexBuffers, offsets );
+        // std::array<vk::Buffer,1> vertexBuffers { m_vertexBuffer };
+        // std::array<vk::DeviceSize,1> offsets { 0 };
+        commandBuffer.bindVertexBuffers( 0, *m_vertexBuffer, vk::DeviceSize{0} );
+        commandBuffer.bindIndexBuffer( m_indexBuffer, 0, vk::IndexType::eUint16 );
 
-        commandBuffer.draw(static_cast<uint32_t>(vertices.size()), 1, 0, 0);
+        commandBuffer.drawIndexed(static_cast<uint32_t>(indices.size()), 1, 0, 0, 0);
 
         commandBuffer.endRenderPass();
         commandBuffer.end();
@@ -819,9 +823,13 @@ private:
         }
     };
     inline static const std::vector<Vertex> vertices = {
-        {{0.0f, -0.5f}, {1.0f, 1.0f, 1.0f}},
-        {{0.5f, 0.5f}, {0.0f, 1.0f, 0.0f}},
-        {{-0.5f, 0.5f}, {0.0f, 0.0f, 1.0f}}
+        {{-0.5f, -0.5f}, {1.0f, 0.0f, 0.0f}},
+        {{0.5f, -0.5f}, {0.0f, 1.0f, 0.0f}},
+        {{0.5f, 0.5f}, {0.0f, 0.0f, 1.0f}},
+        {{-0.5f, 0.5f}, {1.0f, 1.0f, 1.0f}}
+    };
+    inline static const std::vector<uint16_t> indices = {
+        0, 1, 2, 2, 3, 0
     };
     /////////////////////////////////////////////////////////////////
 
@@ -878,6 +886,33 @@ private:
 
         copyBuffer(stagingBuffer, m_vertexBuffer, bufferSize);
     }
+    void createIndexBuffer() {
+        vk::DeviceSize bufferSize = sizeof(indices[0]) * indices.size();
+
+        vk::raii::DeviceMemory stagingBufferMemory{ nullptr };
+        vk::raii::Buffer stagingBuffer{ nullptr };
+        createBuffer(bufferSize, 
+            vk::BufferUsageFlagBits::eTransferSrc, 
+            vk::MemoryPropertyFlagBits::eHostVisible | 
+            vk::MemoryPropertyFlagBits::eHostCoherent,
+            stagingBuffer, 
+            stagingBufferMemory
+        );
+
+        void* data = stagingBufferMemory.mapMemory(0, bufferSize);
+        memcpy(data, indices.data(), static_cast<size_t>(bufferSize));
+        stagingBufferMemory.unmapMemory();
+
+        createBuffer(bufferSize, 
+            vk::BufferUsageFlagBits::eTransferDst |
+            vk::BufferUsageFlagBits::eIndexBuffer, 
+            vk::MemoryPropertyFlagBits::eDeviceLocal,
+            m_indexBuffer, 
+            m_indexBufferMemory
+        );
+
+        copyBuffer(stagingBuffer, m_indexBuffer, bufferSize);
+    }
     void copyBuffer(vk::raii::Buffer& srcBuffer, vk::raii::Buffer& dstBuffer, vk::DeviceSize size) {
         vk::CommandBufferAllocateInfo allocInfo;
         allocInfo.level = vk::CommandBufferLevel::ePrimary;
